==> 0.0.1%2B1.tar.gz: lib/models/IR5CarteOnglet.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;
import "IR5CarteBtn.dart" show IR5CarteBtn;

// --------------------------------------------------------------------------------
part 'IR5CarteOnglet.g.dart';

/** Carte Onglets */
@JsonSerializable(explicitToJson: true)
class IR5CarteOnglet {
  IR5CarteOnglet({
    required this.Onglet,
    required this.Nom,
    required this.BtnText,
    required this.Order_Index,
    required this.Flags,
    required this.TariffIn,
    required this.TariffOut,
    required this.Btns,
    required this.Categorie,
    required this.Groupe,
    required this.Cols,
    required this.Rows,
    required this.BtnProp,
  });

  factory IR5CarteOnglet.fromJson(Map<String, dynamic>? json) => _$IR5CarteOngletFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5CarteOngletToJson(this);

  @JsonKey(defaultValue: 0)
  final num Onglet;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: '')
  final String BtnText;
  @JsonKey(defaultValue: 0)
  final num Order_Index;

  /** Onglet Flags
   *   Bit 00 : Invisible
   *   Bit 01 : ResizeBtns
   *   Bit 02 : 08x12Btns
   *   Bit 03 : 12x12Btns
   *   Bit 04 : 16x16Btns
   *   Bit 09 : ForcedIN
   *   Bit 10 : ForcedOUT
   *   Bit 11 : ForceDesti
   *   Bit 19 : RestomaxExcluded
   *   Bit 20 : TelemaxExcluded
   *   Bit 24 : ForcedZero
   *   Bit 25 : ForcedHappyHour
   *   Bit 29 : TarifIN1
   *   Bit 30 : TarifIN2
   *   Bit 31 : TarifIN3
   *   Bit 32 : TarifIN4
   *   Bit 39 : TarifOUT1
   *   Bit 40 : TarifOUT2
   *   Bit 41 : TarifOUT3
   *   Bit 42 : TarifOUT4
   *   Bit 58 : IsTagsSearch
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Tariff In. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if IN(resto) */
  @JsonKey(defaultValue: 0)
  final num TariffIn;

  /** Tariff Out. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if OUT(emport) */
  @JsonKey(defaultValue: 0)
  final num TariffOut;

  /** Onglet Btns Origin : BtnsList OR Categorie OR Groupe */
  @JsonKey(defaultValue: [])
  final List<IR5CarteBtn> Btns;
  @JsonKey(defaultValue: '')
  final String Categorie;
  @JsonKey(defaultValue: 0)
  final num Groupe;
  @JsonKey(defaultValue: 0)
  final num Cols;
  @JsonKey(defaultValue: 0)
  final num Rows;

  final IR5BtnProperties BtnProp;
/** Flags Getters */
}

==> 0.0.2%2B1.tar.gz: lib/models/IR5CarteOnglet.dart <==
import 'package:json_annotation/json_annotation.dart';

import "IR5BtnProperties.dart" show IR5BtnProperties;
import "IR5CarteBtn.dart" show IR5CarteBtn;

// --------------------------------------------------------------------------------
part 'IR5CarteOnglet.g.dart';

/** Carte Onglets */
@JsonSerializable(explicitToJson: true)
class IR5CarteOnglet {
  IR5CarteOnglet({
    required this.Onglet,
    required this.Nom,
    required this.BtnText,
    required this.Order_Index,
    required this.Flags,
    required this.TariffIn,
    required this.TariffOut,
    required this.Btns,
    required this.Categorie,
    required this.Groupe,
    required this.Cols,
    required this.Rows,
    required this.BtnProp,
  });

  factory IR5CarteOnglet.fromJson(Map<String, dynamic>? json) =>
      _$IR5CarteOngletFromJson(json ?? {});
  Map<String, dynamic> toJson() => _$IR5CarteOngletToJson(this);

  @JsonKey(defaultValue: 0)
  final num Onglet;
  @JsonKey(defaultValue: '')
  final String Nom;
  @JsonKey(defaultValue: '')
  final String BtnText;
  @JsonKey(defaultValue: 0)
  final num Order_Index;

  /** Onglet Flags
   *   Bit 00 : Invisible
   *   Bit 01 : ResizeBtns
   *   Bit 02 : 08x12Btns
   *   Bit 03 : 12x12Btns
   *   Bit 04 : 16x16Btns
   *   Bit 09 : ForcedIN
   *   Bit 10 : ForcedOUT
   *   Bit 11 : ForceDesti
   *   Bit 19 : RestomaxExcluded
   *   Bit 20 : TelemaxExcluded
   *   Bit 24 : ForcedZero
   *   Bit 25 : ForcedHappyHour
   *   Bit 29 : TarifIN1
   *   Bit 30 : TarifIN2
   *   Bit 31 : TarifIN3
   *   Bit 32 : TarifIN4
   *   Bit 39 : TarifOUT1
   *   Bit 40 : TarifOUT2
   *   Bit 41 : TarifOUT3
   *   Bit 42 : TarifOUT4
   *   Bit 58 : IsTagsSearch
   */
  @JsonKey(defaultValue: 0)
  final num Flags;

  /** Tariff In. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if IN(resto) */
  @JsonKey(defaultValue: 0)
  final num TariffIn;

  /** Tariff Out. Can be a TblTariff(1,2,3,4) or any TariffColor(Id>999) */

  /** Tariff Color to use if OUT(emport) */
  @JsonKey(defaultValue: 0)
  final num TariffOut;

  /** Onglet Btns Origin : BtnsList OR Categorie OR Groupe */
  @JsonKey(defaultValue: [])
  final List<IR5CarteBtn> Btns;
  @JsonKey(defaultValue: '')
  final String Categorie;
  @JsonKey(defaultValue: 0)
  final num Groupe;
  @JsonKey(defaultValue: 0)
  final num Cols;
  @JsonKey(defaultValue: 0)
  final num Rows;

  final IR5BtnProperties BtnProp;
/** Flags Getters */
}
